@@ -111,6 +111,65 @@ def linux(ctx, bucket, cert_key, private_key, services=None, profile=None):
             ctx.run(f'systemctl reload {x}')
 
 
+@task
+def redis(
+        ctx, bucket, cert_key, private_key, redis_dir='/var/lib/redis',
+        host=None, port=6379, profile=None):
+    """
+    installs certs and keys to redis_dir
+    uses the redis-cli to update the certs
+    """
+    from boto3 import Session
+    session = Session(profile_name=profile)
+    s3 = session.client('s3')
+    cert = os.path.join(redis_dir, 'redis.crt')
+    s3.download_file(bucket, cert_key, cert)
+    key = os.path.join(redis_dir, 'redis.key')
+    s3.download_file(bucket, private_key, key)
+    host = host or os.environ.get('HOST')
+    with ctx.cd(redis_dir):
+        for x in cert, key:
+            ctx.run(f'chown redis:redis {x}')
+        ctx.run(f'chmod 0640 {key}')
+        ctx.run(f'chmod 0644 {cert}')
+    ctx.run(
+        f'redis-cli --tls -h {host} -p {port} config '
+        f'set tls-cert-file "{os.path.basename(cert)}"')
+    ctx.run(
+        f'redis-cli --tls -h {host} -p {port} config '
+        f'set tls-key-file "{os.path.basename(key)}"')
+
+
+@task
+def postgres(
+        ctx, bucket, cert, key, dest_dir='/etc/postgresql/ssl',
+        reload=True, command='pg_ctlcluster 15 main reload',
+        config_file=None, profile=None):
+    """
+    installs certs and keys to dest_dir as postgres.crt and postgres.key
+    by default, we will call the reload command specified after downloading
+    to force postgres to reload the ssl certs
+    if config_file is specified, the installer will update the
+    `ssl_cert_file` and `ssl_key_file` parameters using sed
+    """
+    from boto3 import Session
+    session = Session(profile_name=profile)
+    s3 = session.client('s3')
+    dest_cert = os.path.join(dest_dir, 'postgres.crt')
+    s3.download_file(bucket, cert, dest_cert)
+    dest_key = os.path.join(dest_dir, 'postgres.key')
+    s3.download_file(bucket, key, dest_key)
+    for x in dest_cert, dest_key:
+        ctx.run(f'chown postgres:postgres {x}')
+    ctx.run(f'chmod 0600 {dest_key}')
+    ctx.run(f'chmod 0644 {dest_cert}')
+    if config_file:
+        ctx.run(f"sed -i -e 's,^ssl_cert_file.*,ssl_cert_file = '\"'\"'{dest_cert}'\"'\"',g' {config_file}")
+        ctx.run(f"sed -i -e 's,^ssl_key_file.*,ssl_key_file = '\"'\"'{dest_key}'\"'\"',g' {config_file}")
+    if reload:
+        ctx.run(command)
+
+
 @task
 def xrdp(ctx, bucket, cert_key, private_key, profile=None):
     """
@@ -158,7 +217,7 @@ def iis(ctx, bucket, key, sites='', password=None, profile=None):
             Write-Host "skipping $($binding.bindingInformation), cert already installed"
             continue
         }
-        Write-Host "updating certificate for $($binding.bindingInformation)"  
+        Write-Host "updating certificate for $($binding.bindingInformation)"
         $binding.addSslCertificate($thumbprint, 'my')
     }
     """
@@ -218,6 +277,56 @@ def rds(ctx, bucket, key, password=None, profile=None):
     ctx.run(c)
 
 
+@task
+def winrm(ctx, bucket, key, password=None, profile=None):
+    """
+    installs pfx to `cert:/localmachine/my`
+    installs cert for use with winrm
+
+    if you encounter ssl error 234, check the sslbindings https://stackoverflow.com/questions/21859308/failed-to-enumerate-ssl-bindings-error-code-234
+    if you encounter internal error with SSL library, that usually means you have to enable schannel for tls 1.2
+      https://docs.rackspace.com/support/how-to/enabling-tls-1.2-on-windows-server/
+    """
+    from .sewer import install_cert_on_windows
+    thumbprint = install_cert_on_windows(
+        ctx, bucket, key, profile, password, 'my')
+    c = (
+        rf"""
+        $thumbprint = '{thumbprint}'
+        $cert = Get-Item "cert:/localmachine/my/$($thumbprint)"
+        $filename = $cert.privatekey.cspkeycontainerinfo.uniquekeycontainername
+        $root = 'c:\programdata\microsoft\crypto\rsa\machinekeys'
+        $p = [io.path]::combine($root, $filename)
+        $root = 'c:\programdata\microsoft\crypto\keys'
+        $private_key = [Security.Cryptography.X509Certificates.RSACertificateExtensions]::GetRSAPrivateKey($cert)
+        $q = $private_key.key.UniqueName
+        $q = [io.path]::combine($root, $q)
+        $rule = new-object security.accesscontrol.filesystemaccessrule 'NETWORK SERVICE', 'Read', allow
+        foreach ($x in @($p, $q)) {'{'}
+            if ([io.file]::exists($p)) {'{'}
+                $acl = get-acl -path $x
+                $acl.addaccessrule($rule)
+                echo "modifying acl on $x"
+                set-acl $x $acl
+            {'}'}
+        {'}'}
+        $valueset = @{'{'}
+            Hostname = $cert.subject.split("=", 2)[1]
+            CertificateThumbprint = $thumbprint
+        {'}'}
+
+        $selectorset = @{'{'}
+            Transport = "HTTPS"
+            Address = "*"
+        {'}'}
+        Remove-WSManInstance -ResourceURI 'winrm/config/Listener' -SelectorSet $selectorset
+        New-WSManInstance -ResourceURI 'winrm/config/Listener' -SelectorSet $selectorset -ValueSet $valueset
+        """
+    )
+    print(c)
+    ctx.run(c)
+
+
 @task
 def exchange(ctx, bucket, key, connector=None, password=None, profile=None):
     from sedge.sewer import install_cert_on_windows
@@ -247,4 +356,7 @@ installers_collection = Collection(
     exchange,
     rds,
     xrdp,
+    winrm,
+    redis,
+    postgres,
 )
