@@ -3,6 +3,7 @@ from dataclasses import dataclass
 from glob import glob
 import logging
 import os
+import platform
 import posixpath
 import socket
 import sys
@@ -694,11 +695,10 @@ def install_cert_on_windows(
     thumbprint = cert.fingerprint(hashes.SHA1()).hex().upper()
     f = NamedTemporaryFile(mode='w', delete=False)  # pylint: disable=consider-using-with
     filename = f.name
-    print('importing pfx to cert store')
+    print(f'importing pfx to cert store from {filename}')
     with open(filename, 'wb') as f:
         f.write(pfx_data)
-    cmdlet = """
-    """
+    cmdlet = ''
     e = {}
     if pfx_password:
         password = '-password (ConvertTo-SecureString -f -a $env:SEDGE_PASSWORD)'
@@ -709,6 +709,37 @@ def install_cert_on_windows(
         store_arg = rf"-certstorelocation 'cert:\localmachine\{store}'"
     else:
         store_arg = r'-certstorelocation cert:\localmachine\my'
+    if platform.release().startswith('2008'):
+        cmdlet = """
+        function Import-PfxCertificate {
+            param([string]$filepath
+              , [string]$root_store = 'localmachine'
+              , [string]$store = 'My'
+              , [security.securestring]$password = $null)
+            Write-Host "importing $filepath"
+            using namespace System.Security.Cryptography.X509Certificates
+            $pfx = new-object X509Certificate2
+            $flags = [X509KeyStorageFlags]::Exportable
+            $flags = $flags -bor [X509KeyStorageFlags]::MachineKeySet
+            $flags = $flags -bor [X509KeyStorageFlags]::PersistKeySet
+            $pfx.import($filepath, $password, $flags)
+            $p = new-object X509Store($store, $root_store)
+            $p.open('MaxAllowed')
+            $exists = $false
+            foreach ($x in $p.certificates) {
+                if ($x.thumbprint -eq $pfx.thumbprint) {
+                    Write-Host 'cert already exists in cert store'
+                    $exists = $true
+                }
+            }
+            if (!($exists)) {
+                $p.add($pfx)
+            }
+            $p.close()
+            return $pfx.thumbprint
+        }
+        """
+        store_arg = ''
     lines = [
         cmdlet,
         f"$t = Import-PfxCertificate -filepath '{filename}' {password} "
